vfbLib.typing.EntryDict
=======================

.. currentmodule:: vfbLib.typing

.. autoclass:: EntryDict
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EntryDict.__init__
      ~EntryDict.clear
      ~EntryDict.copy
      ~EntryDict.fromkeys
      ~EntryDict.get
      ~EntryDict.items
      ~EntryDict.keys
      ~EntryDict.pop
      ~EntryDict.popitem
      ~EntryDict.setdefault
      ~EntryDict.update
      ~EntryDict.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~EntryDict.key
      ~EntryDict.size
      ~EntryDict.data
      ~EntryDict.parser
      ~EntryDict.compiler
   
   